@@ -12,14 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import print_function
-
 import argparse
 import logging
 import sys
 
 from oslo_utils import encodeutils
-import six
 
 import masakariclient
 from masakariclient import cliargs
@@ -201,8 +198,9 @@ def main(args=None):
         if '--debug' in args or '-d' in args:
             raise
         else:
-            print(encodeutils.safe_encode(six.text_type(e)), sys.stderr)
+            print(encodeutils.safe_encode(str(e), sys.stderr))
         return 1
 
+
 if __name__ == "__main__":
     sys.exit(main())
